{% load staticfiles %}
<!DOCTYPE html>
<html lang="en">
<head>
	<title>Abyss - The Tsuru web admin</title>
	<meta charset="UTF-8" />
	<meta name="viewport" content="width=device-width, initial-scale=1.0" />
	<link rel="stylesheet" href="{% static "css/bootstrap.min.css" %}" />
	<link rel="stylesheet" href="{% static "css/abyss.css" %}" />
	<link rel="stylesheet" href="{% static "css/abyss.login.css" %}" />
	<link rel="icon" type="image/x-icon" href="{% static "img/favicon.ico" %}" />
</head>
<body>
	<div class="container">
		<div class="logo">
			<img src="{% static "img/logo.png" %}" />
		</div>

		<p>You've successfully started the password reset process.</p>
		<p>Please check your email.</p>
	</div> <!-- /container -->
</body>
</html>
