{% extends "base.html" %}
{% load staticfiles %}

{% block extra_css %}
<link rel="stylesheet" type="text/css" href="{% static 'css/razorflow.min.css' %}">
<meta name="viewport" content="initial-scale=1.0, user-scalable=no">
{% endblock %}

{% block sidebar %}
{% include "sidebar.html" with active="dashboard" %}
{% endblock %}

{% block content %}
<div id="application" class="dashboard"></div>
{% endblock %}

{% block extra_js %}
<script src="{% static 'js/vendor/razorflow.min.js' %}"></script>
<script src="{% static 'js/lib/dashboard.js' %}"></script>
{% endblock %}
