<div class="navbar navbar-default">
  <div class="navbar-inner">
    <ul class="nav navbar-nav">
      {% for tab in tabs %}
      <li{% if active == tab %} class="active"{% endif %}>
        <a title="{{ tab.name }}" href="{% url tab.url_name app.name %}">{{ tab.name }}</a>
      </li>
      {% endfor %}
    </ul>
  </div>
</div>
